@@ -1,7 +1,9 @@
 from linkml_runtime.dumpers.json_dumper import JSONDumper
 from linkml_runtime.dumpers.rdf_dumper import RDFDumper
 from linkml_runtime.dumpers.yaml_dumper import YAMLDumper
+from linkml_runtime.dumpers.csv_dumper import CSVDumper
 
 json_dumper = JSONDumper()
 rdf_dumper = RDFDumper()
 yaml_dumper = YAMLDumper()
+csv_dumper = CSVDumper()
